# vs-dehalo
Collection of dehaloing VapourSynth functions

## How to use

```py
from vsdehalo import fine_dehalo

src = ...

dehaloed = fine_dehalo(src)
```

## How to install

Install `vsdehalo` with the following command:

```sh
$ pip install vsdehalo
```

Or if you want the latest git version, install it with this command:

```sh
$ pip install git+https://github.com/Irrational-Encoding-Wizardry/vs-dehalo.git
```
<br>
